Further reading
===============

.. toctree ::
:maxdepth: 2

   doc_tests/test_addplugins/test_addplugins.rst
   doc_tests/test_doctest_fixtures/doctest_fixtures.rst
   doc_tests/test_init_plugin/init_plugin.rst
   doc_tests/test_issue089/unwanted_package.rst
   doc_tests/test_issue097/plugintest_environment.rst
   doc_tests/test_issue107/plugin_exceptions.rst
   doc_tests/test_issue119/empty_plugin.rst
   doc_tests/test_issue142/errorclass_failure.rst
   doc_tests/test_issue145/imported_tests.rst
   doc_tests/test_multiprocess/multiprocess.rst
   doc_tests/test_restricted_plugin_options/restricted_plugin_options.rst
   doc_tests/test_selector_plugin/selector_plugin.rst
   doc_tests/test_allmodules/test_allmodules.rst
   doc_tests/test_xunit_plugin/test_skips.rst
   more_info

Articles, etc
-------------

* `An Extended Introduction to the nose Unit Testing Framework`_:
  Titus Brown's excellent article provides a great overview of
  nose and its uses.
* `My blog`_
* `Tweets`_

.. _`An Extended Introduction to the nose Unit Testing Framework` : http://ivory.idyll.org/articles/nose-intro.html
.. _`My blog` : http://somethingaboutorange.com/mrl/
.. _`Tweets` : http://twitter.com/jpellerin